<?php

/**
 * @file
 * Contains \Drupal\snippet_manager\Plugin\SnippetVariable\StaticText.
 */

namespace Drupal\snippet_manager\Plugin\SnippetVariable;

use Drupal\Core\Form\FormStateInterface;
use Drupal\snippet_manager\SnippetVariableBase;
use Drupal\snippet_manager\SnippetVariableInterface;

/**
 * Provides static text variable type.
 *
 * @SnippetVariable(
 *   id = "static_text",
 *   title = @Translation("Static text"),
 *   category = @Translation("Global"),
 * )
 */
class StaticText extends SnippetVariableBase implements SnippetVariableInterface {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {

    $default_value = isset($this->configuration['value']) ?
      $this->configuration['value'] : '';

    $default_format = isset($this->configuration['format']) ?
      $this->configuration['format'] : filter_default_format();

    $form['content'] = array(
      '#title' => t('Content'),
      '#type' => 'text_format',
      '#default_value' => $default_value,
      '#rows' => 10,
      '#format' => $default_format,
      '#editor' => FALSE,
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->configuration['value'] = $values['content']['value'];
    $this->configuration['format'] = $values['content']['format'];
  }

  /**
   * {@inheritdoc}
   */
  public function getContent() {
    return [
      '#type' => 'processed_text',
      '#text' => $this->configuration['value'],
      '#format' => $this->configuration['format'],
    ];
  }

}
