<?php

/**
 * @file
 * Contains \Drupal\snippet_manager\Plugin\SnippetVariable\ViewDeriver.
 */

namespace Drupal\snippet_manager\Plugin\SnippetVariable;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\views\Views;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Retrieves snippet variable plugin definitions for all views.
 */
class ViewDeriver extends DeriverBase implements ContainerDeriverInterface {

  /**
   * Constructs ViewDeriver object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_manager
   *   The entity manager service.
   */
  public function __construct(EntityTypeManagerInterface $entity_manager) {
    $this->entityManager = $entity_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('entity.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {

    foreach (Views::getAllViews() as $view_id => $view) {
      if ($view->status()) {
        $this->derivatives[$view_id] = $base_plugin_definition;
        $this->derivatives[$view_id]['title'] = $view->label();
      }
    }

    return $this->derivatives;
  }

}
