<?php

/**
 * @file
 * Contains \Drupal\snippet_manager\SnippetAdminViewBuilder.
 */

namespace Drupal\snippet_manager;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Entity\EntityViewBuilder;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Render\Element;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a Snippet view builder.
 */
class SnippetAdminViewBuilder extends EntityViewBuilder {

  /**
   * Snippet renderer.
   *
   * @var \Drupal\snippet_manager\SnippetRenderer
   */
  protected $snippetRenderer;

  /**
   * Constructs a new SnippetViewBuilder.
   *
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   *   The entity type definition.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_manager
   *   The entity manager service.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   The language manager.
   * @param \Drupal\snippet_manager\SnippetRenderer $snippet_renderer
   *   Snippet renderer service.
   */
  public function __construct(EntityTypeInterface $entity_type, EntityTypeManagerInterface $entity_manager, LanguageManagerInterface $language_manager, SnippetRenderer $snippet_renderer) {
    parent::__construct($entity_type, $entity_manager, $language_manager);
    $this->snippetRenderer = $snippet_renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    return new static(
      $entity_type,
      $container->get('entity.manager'),
      $container->get('language_manager'),
      $container->get('snippet_manager.renderer')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function view(EntityInterface $entity, $view_mode = 'full', $langcode = NULL) {
    /** @var \Drupal\snippet_manager\SnippetInterface $entity */
    return [
      '#markup' => 'aaaaaaaaa' . $this->snippetRenderer->render($entity),
    ];
  }

}
