<?php

/**
 * @file
 * Contains \Drupal\snippet_manager\SnippetRenderer.
 */

namespace Drupal\snippet_manager;

use Drupal\Core\Template\TwigEnvironment;
use Drupal\Component\Plugin\PluginManagerInterface;

/**
 * SnippetRenderer description.
 */
class SnippetRenderer implements SnippetRendererInterface {

  /**
   * Twig environment.
   *
   * @var \Drupal\Core\Template\TwigEnvironment
   */
  protected $twig;

  /**
   * The variable mamanger.
   *
   * @var \Drupal\Component\Plugin\PluginManagerInterface
   */
  protected $variableManager;

  /**
   * Constructs a SnippetRenderer object.
   *
   * @param \Drupal\Core\Template\TwigEnvironment $twig
   *   The Twig environment.
   * @param \Drupal\Component\Plugin\PluginManagerInterface $variable_manager
   *   Variable manager.
   */
  public function __construct(TwigEnvironment $twig, PluginManagerInterface $variable_manager) {
    $this->twig = $twig;
    $this->variableManager = $variable_manager;
  }

  /**
   * {@inheritdoc}
   */
  public function render(SnippetInterface $snippet) {
    $twig_variables = [];

    foreach ($snippet->getVariables() as $variable_name => $variable) {
      $plugin = $this->variableManager->createInstance(
        $variable['plugin_id'],
        $variable['configuration']
      );

      $twig_variables[$variable_name] = $plugin->getContent();
    }

    $code = $snippet->getCode();

    return $this->twig->renderInline(
      check_markup($code['value'], $code['format']),
      $twig_variables
    );
  }

}
